import type { ColorInput, HSL, HSV, RGB } from './types';
export declare class FastColor {
    /**
     * Red, R in RGB
     */
    r: number;
    /**
     * Green, G in RGB
     */
    g: number;
    /**
     * Blue, B in RGB
     */
    b: number;
    /**
     * Alpha/Opacity, A in RGBA/HSLA
     */
    a: number;
    private _h?;
    private _s?;
    private _l?;
    private _v?;
    private _max?;
    private _min?;
    private _brightness?;
    constructor(input: ColorInput);
    /**
     * Hue, H in HSL/HSV
     */
    get h(): number;
    /**
     * Saturation, S in HSL/HSV
     */
    get s(): number;
    /**
     * Lightness, L in HSL
     */
    get l(): number;
    /**
     * Value, V in HSV
     */
    get v(): number;
    get isValid(): boolean;
    clone(): FastColor;
    equals(other: FastColor): boolean;
    darken(amount?: number): FastColor;
    lighten(amount?: number): FastColor;
    /**
     * Mix the color with pure white, from 0 to 100.
     * Providing 0 will do nothing, providing 100 will always return white.
     */
    tint(amount?: number): FastColor;
    /**
     * Mix the color with pure black, from 0 to 100.
     * Providing 0 will do nothing, providing 100 will always return black.
     */
    shade(amount?: number): FastColor;
    /**
     * Mix the current color a given amount with another color, from 0 to 100.
     * 0 means no mixing (return current color).
     */
    mix(color: ColorInput, amount?: number): FastColor;
    getAlpha(): number;
    /**
     * Returns the perceived luminance of a color, from 0-1.
     * @see http://www.w3.org/TR/2008/REC-WCAG20-20081211/#relativeluminancedef
     */
    getLuminance(): number;
    getHue(): number;
    getSaturation(): number;
    getLightness(): number;
    getValue(): number;
    isDark(): boolean;
    isLight(): boolean;
    /**
     * Returns the perceived brightness of the color, from 0-255.
     * @see http://www.w3.org/TR/AERT#color-contrast
     */
    getBrightness(): number;
    onBackground(background: ColorInput): FastColor;
    setAlpha(alpha: number): FastColor;
    toHexString(): string;
    toHsl(): HSL;
    toHslString(): string;
    toHsv(): HSV;
    toRgb(): RGB;
    toRgbString(): string;
    toString(): string;
    private get max();
    private get min();
    private fromHexString;
    private fromHsl;
    private fromHsv;
    private fromHslString;
    private fromRgbString;
}
